## [1.1.4](https://github.com/panthrocorp/github-account-switcher/compare/v1.1.3...v1.1.4) (2026-03-02)

### Bug Fixes

* add missing PyPI project metadata ([#6](https://github.com/panthrocorp/github-account-switcher/issues/6)) ([1bd2a76](https://github.com/panthrocorp/github-account-switcher/commit/1bd2a76fda8feee3505aaadef147f826f8fb5b03))

## [1.1.3](https://github.com/panthrocorp/github-account-switcher/compare/v1.1.2...v1.1.3) (2026-03-02)

### Bug Fixes

* pass tag input when dispatching publish workflow ([#5](https://github.com/panthrocorp/github-account-switcher/issues/5)) ([c37450e](https://github.com/panthrocorp/github-account-switcher/commit/c37450ec498e031e16feeafb1c476b590a3fe0c7))

## [1.1.2](https://github.com/panthrocorp/github-account-switcher/compare/v1.1.1...v1.1.2) (2026-03-02)

### Bug Fixes

* trigger publish workflow from CI after release ([#4](https://github.com/panthrocorp/github-account-switcher/issues/4)) ([bc20c4e](https://github.com/panthrocorp/github-account-switcher/commit/bc20c4e73074d35589e9d79b112d79c0993b7727))

## [1.1.1](https://github.com/panthrocorp/github-account-switcher/compare/v1.1.0...v1.1.1) (2026-03-02)

### Bug Fixes

* guard BASH_SOURCE against unbound in curl pipe ([#3](https://github.com/panthrocorp/github-account-switcher/issues/3)) ([e40049b](https://github.com/panthrocorp/github-account-switcher/commit/e40049ba823faeeb2a291a374de384b9c1188d9c))

## [1.1.0](https://github.com/panthrocorp/github-account-switcher/compare/v1.0.0...v1.1.0) (2026-03-02)

### Features

* add test suite, installer, and packaging ([#2](https://github.com/panthrocorp/github-account-switcher/issues/2)) ([60348dd](https://github.com/panthrocorp/github-account-switcher/commit/60348dd1487fbe73431381543ae8b3ae4cd05037))

## 1.0.0 (2026-02-27)

### Features

* add gh-switcher system tray app ([#1](https://github.com/panthrocorp/github-account-switcher/issues/1)) ([40bfb13](https://github.com/panthrocorp/github-account-switcher/commit/40bfb13e56ee1744e302aef3e6b70004dd316666))
